//
//  AliyunAnswerPlayerViewController.m
//  AliyunPlayerMediaDemo
//
//  Created by 王凯 on 2018/1/16.
//  Copyright © 2018年 com.alibaba.ALPlayerVodSDK. All rights reserved.
//

#import "AliyunAnswerPlayerViewController.h"
#import "UIView+Layout.h"
#import "AliyunAnswerView.h"
#import "AliyunAnswerLogView.h"
#import <AliyunPlayerSDK/AliyunPlayerSDK.h>
#import "AliyunLiveQuestionManager.h"

//请求地址
#define REQUEST_URL @"http://101.132.137.92"

@interface AliyunAnswerPlayerViewController ()<AliyunAnswerViewDelegate,AliyunLiveQuestionDelegate>
{
    int mRetryCount;
}

//播放器部分
@property (nonatomic, strong) AliVcMediaPlayer *mediaPlayer;
@property (nonatomic, strong) UIView *contentView;

//log
@property (nonatomic, strong) AliyunAnswerLogView *showMessageView;

//题目界面
@property (nonatomic, strong)AliyunAnswerView *answerView;

@end

@implementation AliyunAnswerPlayerViewController

-(AliyunAnswerLogView *)showMessageView{
    if (!_showMessageView){
        _showMessageView = [[AliyunAnswerLogView alloc] init];
        _showMessageView.backgroundColor = [UIColor clearColor];//[UIColor colorWithWhite:0.5 alpha:0.8];
        _showMessageView.alpha = 1;

    }
    
    return _showMessageView;
}


- (AliyunAnswerView *)answerView{
    if (!_answerView) {
        _answerView = [[AliyunAnswerView alloc] init];
        _answerView.layer.borderWidth = 1;
        _answerView.layer.masksToBounds = YES;
        _answerView.layer.cornerRadius = 10;
        _answerView.hidden = YES;
        _answerView.delegate = self;
        
    }
    return _answerView;
}

-(AliVcMediaPlayer *)mediaPlayer{
    if (!_mediaPlayer) {
        //1.创建播放器
        _mediaPlayer = [[AliVcMediaPlayer alloc] init];
    }
    return _mediaPlayer;
}

- (UIView *)contentView{
    if (!_contentView) {
        _contentView = [[UIView alloc] init];
    }
    return _contentView;
}

-(void)player{
    
    self.contentView.frame = CGRectMake(0, 0, self.view.width, self.view.height-64);
    [self.view addSubview:self.contentView];
    [self.mediaPlayer create:self.contentView];
    self.mediaPlayer.scalingMode = scalingModeAspectFit;
    self.mediaPlayer.circlePlay = YES;
    self.mediaPlayer.dropBufferDuration = 3000;
//    self.mediaPlayer.printLog = YES;
    AliVcMovieErrorCode err = [self.mediaPlayer prepareToPlay:[NSURL URLWithString:self.playUrl]];
    //5.判定错误，是否可以播放。
    if (err != ALIVC_SUCCESS) {
        NSLog(@"chinese-播放失败");
    }else{
        [self.mediaPlayer play];
        [UIApplication sharedApplication].idleTimerDisabled = YES;
    }
    mRetryCount = 0;
}

#pragma mark - naviBar
- (void)InitNaviBar{
    NSString *backString = NSLocalizedString(@"Back", nil);
    
    NSString *logString = NSLocalizedString(@"Log", nil);
    self.navigationItem.leftBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:backString style:UIBarButtonItemStylePlain target:self action:@selector(returnButtonItemCliceked:)];
    self.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:logString style:UIBarButtonItemStylePlain target:self action:@selector(LogButtonItemCliceked:)];
}

- (void)returnButtonItemCliceked:(UIBarButtonItem*)sender{
    
    sender.enabled = NO;
    if (self.answerView){
        [self.answerView clear];
    }
    if(self.mediaPlayer){
        [self removePlayerObserver];
        [self.mediaPlayer stop];
        [self.mediaPlayer destroy];
        self.mediaPlayer = nil;
    }
    [self.navigationController popViewControllerAnimated:YES];
    sender.enabled = YES;
    [UIApplication sharedApplication].idleTimerDisabled = NO;
}
- (void)LogButtonItemCliceked:(UIBarButtonItem*)sender{
    self.showMessageView.hidden = NO;
}

#pragma mark - viewDidLoad
- (void)viewDidLoad {
    [super viewDidLoad];
    
    UIImageView *imageView = [[UIImageView alloc] initWithImage:[UIImage imageNamed:@"timg"]];
    imageView.frame = CGRectMake(0, 0, self.view.width, self.view.height);
    [self.view addSubview:imageView];
    
    //navigationbar
    [self InitNaviBar];
    //view
    self.edgesForExtendedLayout = UIRectEdgeNone;
    self.view.backgroundColor = [UIColor grayColor];
    self.title  = @"直播间";
    
    //播放器
    [self player];
    [self addPlayerObserver];
    
    //题目界面
    self.answerView.frame = CGRectMake((self.view.width-280)/2, 84, 280, 330);
    self.answerView.backgroundColor = [UIColor whiteColor];
    [self.view addSubview:self.answerView];
    
    self.showMessageView.hidden = YES;
    [self.view addSubview:self.showMessageView];
    
    [AliyunLiveQuestionManager shareManager].delegate = self;
    [AliyunLiveQuestionManager shareManager].mLiveId = self.liveId;
}

- (void)viewWillLayoutSubviews{
    [super viewWillLayoutSubviews];
    self.showMessageView.frame = self.view.bounds;
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark - add NSNotification 播放器通知
-(void)addPlayerObserver
{
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(OnVideoPrepared:)
                                                 name:AliVcMediaPlayerLoadDidPreparedNotification object:self.mediaPlayer];
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(OnVideoFinish:)
                                                 name:AliVcMediaPlayerPlaybackDidFinishNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(OnVideoError:)
                                                 name:AliVcMediaPlayerPlaybackErrorNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(OnSeekDone:)
                                                 name:AliVcMediaPlayerSeekingDidFinishNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(OnStartCache:)
                                                 name:AliVcMediaPlayerStartCachingNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(OnEndCache:)
                                                 name:AliVcMediaPlayerEndCachingNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(onVideoStop:)
                                                 name:AliVcMediaPlayerPlaybackStopNotification object:self.mediaPlayer];
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(onVideoFirstFrame:)
                                                 name:AliVcMediaPlayerFirstFrameNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(onCircleStart:)
                                                 name:AliVcMediaPlayerCircleStartNotification object:self.mediaPlayer];
    
    //直播答题接收的消息
    [[NSNotificationCenter defaultCenter] addObserver:self
                                             selector:@selector(onSeiData:)
                                                 name:AliVcMediaPlayerSeiDataNotification object:self.mediaPlayer];
    
    
}
#pragma mark - remove NSNotification
-(void)removePlayerObserver
{

    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerLoadDidPreparedNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerPlaybackErrorNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerPlaybackDidFinishNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerSeekingDidFinishNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerStartCachingNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerEndCachingNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerPlaybackStopNotification object:self.mediaPlayer];
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerFirstFrameNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerCircleStartNotification object:self.mediaPlayer];
    
    [[NSNotificationCenter defaultCenter] removeObserver:self
                                                    name:AliVcMediaPlayerSeiDataNotification object:self.mediaPlayer];
    
    
    [[NSNotificationCenter defaultCenter] removeObserver:self];
}


#pragma mark - receive
- (void)OnVideoPrepared:(NSNotification *)notification{
    NSLog(@"OnVideoPrepared");
    [self.showMessageView addTextString:NSLocalizedString(@"onVideoPrepared",nil)];
    mRetryCount = 0;
}

- (void)onVideoFirstFrame :(NSNotification *)notification{
    NSLog(@"onVideoFirstFrame");
    [self.showMessageView addTextString:NSLocalizedString(@"onVideoFirstFrame",nil)];
}


- (void)OnVideoError:(NSNotification *)notification{
    NSLog(@"OnVideoError");
    NSDictionary* userInfo = [notification userInfo];
    NSString* errorMsg = [userInfo objectForKey:@"errorMsg"];
    NSNumber* errorCodeNumber = [userInfo objectForKey:@"error"];
    NSLog(@"%@-%@",errorMsg,errorCodeNumber);
    
    [self.showMessageView addTextString:[NSString stringWithFormat:@"%@-%@",errorCodeNumber,errorMsg]];
    
    if(self.mediaPlayer.errorCode == ALIVC_ERR_LOADING_TIMEOUT && mRetryCount<5){
        [self performSelector:@selector(retryPlayMethod) withObject:nil afterDelay:1.0];
    }
}

-(void)retryPlayMethod
{
    if(self.mediaPlayer){
        NSLog(@"retryPlay 重新连接");
        [self.mediaPlayer stop];
        [self.mediaPlayer prepareToPlay:[NSURL URLWithString:self.playUrl]];
        [self.mediaPlayer play];
        mRetryCount++;
    }
}

- (void)OnVideoFinish:(NSNotification *)notification{
    NSLog(@"OnVideoFinish");
    [self.showMessageView addTextString:NSLocalizedString(@"OnVideoFinish",nil)];
}
- (void)OnSeekDone:(NSNotification *)notification{
    NSLog(@"OnSeekDone");
    [self.showMessageView addTextString:NSLocalizedString(@"OnSeekDone",nil)];
}
- (void)OnStartCache:(NSNotification *)notification{
    NSLog(@"OnStartCache");
    [self.showMessageView addTextString:NSLocalizedString(@"OnStartCache",nil)];
}
- (void)OnEndCache:(NSNotification *)notification{
   NSLog(@"OnEndCache");
    [self.showMessageView addTextString:NSLocalizedString(@"OnEndCache",nil)];
}

- (void)onVideoStop:(NSNotification *)notification{
   NSLog(@"onVideoStop");
    [self.showMessageView addTextString:NSLocalizedString(@"OnVideoStop",nil)];
}

- (void)onCircleStart:(NSNotification *)notification{
    NSLog(@"onCircleStart");
    [self.showMessageView addTextString:NSLocalizedString(@"onCircleStart",nil)];
}

//倒计时结束结束，是否是答案窗口
-(void)popQuestionEnd:(BOOL)answeredWindow
{
    self.answerView.hidden = YES;
    self.answerView.alpha = 1;
    
    [UIView animateWithDuration:0.5 animations:^{
        self.contentView.frame = CGRectMake(0, 0, self.view.width, self.view.height);
    } completion:^(BOOL finished) {
        
    }];
    
    [self.showMessageView addTextString:[NSString stringWithFormat:@"answeredWindow--%d",answeredWindow]];
}

//显示日志
-(void)addLogText:(NSString *)logStr
{
    dispatch_async(dispatch_get_main_queue(), ^{
        [self.showMessageView addTextString:logStr];
    });
}

//回调，弹出题目
-(void)popQuestion:(AliyunLiveQuestion *)liveQuestion
{
    dispatch_async(dispatch_get_main_queue(), ^{
        self.answerView.hidden = NO;
        [self.answerView popQuestion:liveQuestion];
        [self.showMessageView addTextString:@"回调，弹出题目 popQuestion"];

        //切换界面
        if(liveQuestion.remainSeconds > 3){
            [UIView animateWithDuration:1 animations:^{
                CGRect frame = self.contentView.frame;
                frame.size.width = 125;
                frame.size.height = 215;
                frame.origin.x = self.view.width - 145;
                frame.origin.y = self.view.height - 235;
                self.contentView.frame = frame;
            } completion:^(BOOL finished) {
            }];
        }
    });
}

//回调，弹出结果
-(void)popAnswer:(AliyunLiveQuestion *)liveQuestion
{
    dispatch_async(dispatch_get_main_queue(), ^{
        self.answerView.hidden = NO;
        [self.answerView popAnswer:liveQuestion];
        [self.showMessageView addTextString:@"回调，弹出结果 popAnswer"];
    });
}

//答题
- (void)onSeiData:(NSNotification *)notification{
    NSLog(@"onSeiData");
    [self.showMessageView addTextString:@"onSeiData"];
    
    NSDictionary* dict = [notification userInfo];
    if (dict) {
        NSString* seiData = [dict objectForKey:@"seiData"];
        if (seiData) {
            NSLog(@"sei data is %@",seiData);
            
            [self.answerView clear];
            [[AliyunLiveQuestionManager shareManager] parseSEIData:seiData];
        }
    }
}

#pragma mark - 竖屏
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)toInterfaceOrientation{
    return (toInterfaceOrientation == UIInterfaceOrientationPortrait);
}

- (BOOL)shouldAutorotate{
    return NO;
}

-(UIInterfaceOrientationMask)supportedInterfaceOrientations{
    return UIInterfaceOrientationMaskPortrait;
}

@end
