//
//  AliyunAnswerView.m
//  AliyunPlayerMediaDemo
//
//  Created by 王凯 on 2018/1/16.
//  Copyright © 2018年 com.alibaba.ALPlayerVodSDK. All rights reserved.
//

#import "AliyunAnswerView.h"
#import "AliyunAnswerCell.h"
#import "UIView+Layout.h"
#import "AliyunLiveQuestionManager.h"

@interface AliyunAnswerView()<UITableViewDelegate,UITableViewDataSource>
{
    AliyunLiveQuestion* mLiveQuestionModel;
    BOOL    mIsAnswering;
}

@property (nonatomic,strong) UILabel *statusLabel;
@property (nonatomic,strong) UILabel *subjectLabel;
@property (nonatomic,assign) float totalHeight;
@property (nonatomic, assign) int answerStatus;
@property (nonatomic, strong) UITableView *tableView;
@property (nonatomic, strong) dispatch_source_t timer;

@property (nonatomic, copy) NSString * statusMessage;

@end
@implementation AliyunAnswerView

-(UITableView *)tableView{
    if (!_tableView) {
        _tableView = [[UITableView alloc]initWithFrame:CGRectZero style:UITableViewStyleGrouped];
        _tableView.backgroundColor = [UIColor clearColor];
        _tableView.delegate = self;
        _tableView.dataSource = self;
        _tableView.scrollEnabled = NO;
        _tableView.tableFooterView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 0, CGFLOAT_MIN)];;
        _tableView.tableHeaderView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, 0, CGFLOAT_MIN)];
        
    }
    return  _tableView;
}

- (UILabel *)statusLabel{
    if(!_statusLabel){
        _statusLabel = [[UILabel alloc] init];
        _statusLabel.text  = @"";
        _statusLabel.font = [UIFont systemFontOfSize:24.0f];
        _statusLabel.textColor = [UIColor blackColor];
        _statusLabel.textAlignment = NSTextAlignmentCenter;
        
        
    }
    return _statusLabel;
}
- (UILabel *)subjectLabel{
    if(!_subjectLabel){
        _subjectLabel = [[UILabel alloc] init];
        _subjectLabel.text  = @"";
        _subjectLabel.font = [UIFont systemFontOfSize:15];
        _subjectLabel.textColor = [UIColor blackColor];
        _subjectLabel.textAlignment = NSTextAlignmentLeft;
    }
    return _subjectLabel;
}

- (instancetype)initWithFrame:(CGRect)frame{
    self = [super initWithFrame:frame];
    if (self) {
        
        self.statusLabel.frame = CGRectMake(0, 15, frame.size.width, 30);
        [self addSubview:self.statusLabel];
        
        self.subjectLabel.frame = CGRectMake(15, self.statusLabel.bottom+10, frame.size.width-30, 50);
        [self addSubview:self.subjectLabel];
        
        self.tableView.frame = CGRectMake(15, self.subjectLabel.bottom+10, frame.size.width-30, 65*3);
        [self addSubview:self.tableView];
        
        mIsAnswering = NO;
    }
    return self;
}

-(void)popAnswer:(AliyunLiveQuestion*)liveQuestion
{
    NSLog(@"popAnswer");
    if (liveQuestion==nil || liveQuestion.options.count<1) {
        NSLog(@"liveQuestion is nil");
        if (self.delegate && [self.delegate respondsToSelector:@selector(popQuestionEnd:)]) {
            [self.delegate popQuestionEnd:YES];
        }
        return;
    }
    
    mLiveQuestionModel = liveQuestion;
    self.statusLabel.frame = CGRectMake(0, 15, self.width, 30);
    
    //计算题目高度
    NSString *str = liveQuestion.questionTitle;
    self.subjectLabel.text = str;
    self.subjectLabel.numberOfLines = 999;
    CGSize size = [str boundingRectWithSize:CGSizeMake(self.width-30, MAXFLOAT) options:NSStringDrawingUsesFontLeading|NSStringDrawingUsesLineFragmentOrigin attributes:@{NSFontAttributeName : [UIFont systemFontOfSize:15.0f ]} context:nil].size;
    self.subjectLabel.frame = CGRectMake(15, self.statusLabel.bottom+10, self.width-30, size.height+10);
    self.totalHeight = self.subjectLabel.bottom;
    
    //选项
    self.tableView.frame = CGRectMake(15, self.subjectLabel.bottom+10, self.width-30, 65*liveQuestion.options.count);
    self.totalHeight += 65*liveQuestion.options.count;
    
    //考虑高度问题,界面越界问题
    if (self.height+10<self.totalHeight) {
        self.height = self.totalHeight;
    }
    
    mIsAnswering = NO;
    __block int count = (int)[AliyunLiveQuestionManager shareManager].mAnswerShowTime;
    NSLog(@"answer showTime -- %d",count);
    if(count<=3) {
        count = 3;
    }

    //更新答题状态
    dispatch_async(dispatch_get_main_queue(), ^{
        //更新cell
        [self tableViewReloadData:NO];
        
        if([[AliyunLiveQuestionManager shareManager] isOut]) {
            self.statusLabel.text = @"已淘汰";
            self.statusLabel.textColor = [UIColor orangeColor];
        }
        else if([[AliyunLiveQuestionManager shareManager] isChooseCorrect]) {
            self.statusLabel.text = @"答对了";
            self.statusLabel.textColor = [UIColor blueColor];
        }
        else {
            self.statusLabel.text = @"答错了";
            self.statusLabel.textColor = [UIColor redColor];
            [[AliyunLiveQuestionManager shareManager] setOuted:YES];
        }
    });

    
    //倒计时
    [self stopTimer];
    dispatch_queue_t queue = dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0);
    self.timer = dispatch_source_create(DISPATCH_SOURCE_TYPE_TIMER, 0, 0, queue);
    dispatch_source_set_timer(_timer, dispatch_walltime(NULL, 0), 1.0 * NSEC_PER_SEC, 0); //每秒执行
    dispatch_source_set_event_handler(_timer, ^{
        if (count <=0) {
            dispatch_async(dispatch_get_main_queue(), ^{
                NSLog(@"count--dispatch_get_main_queue -- %d",count);
                //倒计时结束，通知隐藏窗口
                if (self.delegate && [self.delegate respondsToSelector:@selector(popQuestionEnd:)]) {
                    [self.delegate popQuestionEnd:YES];
                }
            });
            NSLog(@"count--dispatch_get_main_queue1111 -- %d",count);
            dispatch_cancel(self.timer);
            self.timer = nil;
        }
        count  = count - 1;
        NSLog(@"count -- %d",count);
    });
    dispatch_resume(self.timer);
}

-(void)popQuestion:(AliyunLiveQuestion*)liveQuestion
{
    NSLog(@"popQuestion");
    
    if (liveQuestion==nil || liveQuestion.options.count<1) {
        if (self.delegate && [self.delegate respondsToSelector:@selector(popQuestionEnd:)]) {
            [self.delegate popQuestionEnd:NO];
        }
        return;
    }
    
    mLiveQuestionModel = liveQuestion;
    self.statusLabel.frame = CGRectMake(0, 15, self.width, 30);
    
    //计算题目高度
    NSString *str = liveQuestion.questionTitle;
    self.subjectLabel.text = str;
    self.subjectLabel.numberOfLines = 999;
    CGSize size = [str boundingRectWithSize:CGSizeMake(self.width-30, MAXFLOAT) options:NSStringDrawingUsesFontLeading|NSStringDrawingUsesLineFragmentOrigin attributes:@{NSFontAttributeName : [UIFont systemFontOfSize:15.0f ]} context:nil].size;
    self.subjectLabel.frame = CGRectMake(15, self.statusLabel.bottom+10, self.width-30, size.height+10);
    self.totalHeight = self.subjectLabel.bottom;
    
    //选项
    self.tableView.frame = CGRectMake(15, self.subjectLabel.bottom+10, self.width-30, 65*liveQuestion.options.count);
    self.totalHeight += 65*liveQuestion.options.count;
    
    //考虑高度问题,界面越界问题
    if (self.height+10<self.totalHeight) {
        self.height = self.totalHeight;
    }
    
    self.statusLabel.textColor = [UIColor blackColor];
    __block int count = liveQuestion.remainSeconds;
    if (count>10)
        count = 10;
    else if(count<=0)
        count = 5;
    NSLog(@"remainSeconds -- %d",count);
    self.statusLabel.text = [NSString stringWithFormat:@"%d",count];
    NSLog(@"remainSeconds -- | %d |-- |%d|",count,liveQuestion.remainSeconds);
    
    //更新cell
    mIsAnswering = YES;
    BOOL bCanSelect = YES;
    if ([[AliyunLiveQuestionManager shareManager] isOut]) {
        bCanSelect = NO;
    }
    [self tableViewReloadData:bCanSelect];
    
    if([[AliyunLiveQuestionManager shareManager] isOut]) {
        self.statusLabel.text = @"已淘汰";
        self.statusLabel.textColor = [UIColor orangeColor];
    }
    
    //倒计时
    [self stopTimer];
    
    dispatch_queue_t queue = dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0);
    self.timer = dispatch_source_create(DISPATCH_SOURCE_TYPE_TIMER, 0, 0, queue);
    dispatch_source_set_timer(_timer, dispatch_walltime(NULL, 0), 1.0 * NSEC_PER_SEC, 0); //每秒执行
    dispatch_source_set_event_handler(_timer, ^{
        
        if (count <=0) {
            dispatch_async(dispatch_get_main_queue(), ^{
                NSLog(@"count--dispatch_get_main_queue");
                if(![[AliyunLiveQuestionManager shareManager] isOut]) {
                    self.statusLabel.text = @"0";
                }
                //倒计时结束，通知隐藏窗口
                if (self.delegate && [self.delegate respondsToSelector:@selector(popQuestionEnd:)]) {
                    [self.delegate popQuestionEnd:NO];
                }
            });
            dispatch_cancel(self.timer);
            self.timer = nil;
        }else{
            dispatch_async(dispatch_get_main_queue(), ^{
                if(![[AliyunLiveQuestionManager shareManager] isOut]) {
                    self.statusLabel.text = [NSString stringWithFormat:@"%d",count];
                }
            });
            
        }
        
        count  = count - 1;
        NSLog(@"count -- %d",count);
        
        
    });
    dispatch_resume(self.timer);
}

-(void)stopTimer{
    if (self.timer) {
        dispatch_cancel(self.timer);
        self.timer = nil;
    }
}

#pragma mark - tableDelegate/datasource
-(NSInteger)numberOfSectionsInTableView:(UITableView *)tableView{
    
    if (mLiveQuestionModel) {
        return mLiveQuestionModel.options.count;
    }
    return 0;
}

-(NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section{
    return  1;
}

-(UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath{
    static NSString *cellIdentifier = @"democell";
    AliyunAnswerCell *cell = [tableView dequeueReusableCellWithIdentifier:cellIdentifier];\
    if (!cell) {
        cell = [[AliyunAnswerCell alloc] initWithStyle:UITableViewCellStyleDefault reuseIdentifier:cellIdentifier];
    }
    //选中的颜色
    cell.selectedBackgroundView = [[UIView alloc] initWithFrame:CGRectMake(0, 0, cell.width, cell.height)];
    cell.selectedBackgroundView.layer.masksToBounds = YES;
    cell.selectedBackgroundView.layer.cornerRadius = 20;
    cell.selectedBackgroundView.backgroundColor = [UIColor colorWithRed:60/255.0 green:150/255.0 blue:180/255.0 alpha:1];
    
    //正在答题
    if (mIsAnswering && mLiveQuestionModel) {
        AliyunLiveQuestionItem* item = mLiveQuestionModel.options[indexPath.section];
        [cell showQuestionStatus:item];
        NSLog(@"cell -- showQuestionStatus");
    }
    else if(mLiveQuestionModel) {
        AliyunLiveQuestionItem* item = mLiveQuestionModel.options[indexPath.section];
        [cell showAnswerStatus:item totalUserNumber:mLiveQuestionModel.totalUserNumber];
        NSLog(@"cell -- showAnswerStatus:item totalUserNumber:");
    }
    
    

    return cell;
}

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath{
    
    tableView.allowsSelection = NO;
    if (mLiveQuestionModel) {
        AliyunLiveQuestionItem *item = mLiveQuestionModel.options[indexPath.section];
        if(item) {
            item.bChoosed = YES;
            [[AliyunLiveQuestionManager shareManager] AnswerQuestion:item.answerId];
        }
    }
}

- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath{
    return 40.0f;
}

- (UIView*)tableView:(UITableView *)tableView viewForHeaderInSection:(NSInteger)section{
    UIView *view=[[UIView alloc] initWithFrame:CGRectMake(0, 0, 320, 10)];
    view.backgroundColor = [UIColor clearColor];
    return view ;
}

- (CGFloat)tableView:(UITableView *)tableView heightForHeaderInSection:(NSInteger)section{
    return 10;
}

- (UIView*)tableView:(UITableView *)tableView viewForFooterInSection:(NSInteger)section{
    UIView *view=[[UIView alloc] initWithFrame:CGRectMake(0, 0, 320, 10)];
    view.backgroundColor = [UIColor clearColor];
    return view ;
}

- (CGFloat)tableView:(UITableView *)tableView heightForFooterInSection:(NSInteger)section {
    return 10;
}

- (void)tableViewReloadData:(BOOL)allowsSelection{
    if (self.tableView) {
        [self.tableView reloadData];
        self.tableView.allowsSelection = allowsSelection;
    }
}

-(void)clear
{
    [self stopTimer];
}

@end
